<?php

namespace Drupal\config_pages_viewer\Controller;

use Drupal\Core\Entity\Controller\EntityViewController;
use Drupal\config_pages\Entity\ConfigPages;
use Drupal\config_pages\Entity\ConfigPagesType;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Controller for viewing config pages.
 */
class ConfigPageViewerController extends EntityViewController {

  /**
   * Retrieves a ConfigPages entity based on the provided ConfigPagesType.
   *
   * @param \Drupal\config_pages\Entity\ConfigPagesType|null $config_page_type
   *   The Parameters from routing.
   *
   * @return \Drupal\config_pages\Entity\ConfigPages|null
   *   The loaded ConfigPages entity if found, null otherwise.
   */
  private function getConfigPageType(?ConfigPagesType $config_page_type = NULL) {

    if ($config_page_type != NULL) {
      $config_page = ConfigPages::load($config_page_type->id());

      if ($config_page != NULL) {
        return $config_page;
      }
    }

    return NULL;
  }

  /**
   * Render config page.
   *
   * @param Drupal\config_pages\Entity\ConfigPagesType $config_page_type
   *   The Parameters from routing.
   *
   * @return array
   *   Render Array.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the config page cannot be found or loaded.
   */
  public function show(?ConfigPagesType $config_page_type = NULL) {

    $config_page = $this->getConfigPageType($config_page_type);

    if ($config_page === NULL) {
      throw new NotFoundHttpException('Config page not found.');
    }

    // Correct metatags attachment.
    if (function_exists('metatag_get_tags_from_route')) {
      $metatag_attachments = &drupal_static('metatag_attachments');
      $metatag_attachments = metatag_get_tags_from_route($config_page);
    }

    return $this->view($config_page);
  }

  /**
   * Generate dynamic title for the config page.
   *
   * @param \Drupal\config_pages\Entity\ConfigPagesType $config_page_type
   *   Config page type entity.
   *
   * @return string
   *   The page title.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the config page cannot be found or loaded.
   */
  public function getTitle(?ConfigPagesType $config_page_type = NULL): string {

    $config_page = $this->getConfigPageType($config_page_type);

    if ($config_page === NULL) {
      throw new NotFoundHttpException('Config page not found.');
    }

    return $config_page->get('label')->value;
  }

}
